@@ -178,6 +178,14 @@ void QueueView::OnMenubarAction(QAction* action)
 void QueueView::show()
 {
     //overriden show method (handles selection of current playing track etc).
+
+    setListViewState();
+    QMainWindow::show(); //call base
+}
+
+void QueueView::setListViewState()
+{
+    //set current listview state
     QModelIndex index;
     QStandardItem* currTrackItem = NULL;
 
@@ -195,8 +203,6 @@ void QueueView::show()
             m_pTrackInfoView->setCurrentIndex(index); //set the current row in the queue list
         }
     }
-
-    QMainWindow::show(); //call base
 }
 
 void QueueView::OnPlaybackStateChangeRequest(enum pb_state_e requestedState)
@@ -507,7 +513,7 @@ void QueueView::OnPlaybackPositionUpdated(qint64 playbackPos)
     int currPos = (playbackPos*SLIDER_WIDTH) / (m_currTrackDuration*1000);
 
     if(currPos!=m_pProgressSlider->getPos2())
-        m_pProgressSlider->setPos2(currPos); //set curr. slider position
+       m_pProgressSlider->setPos2(currPos); //set curr. slider position
 }
 
 void QueueView::OnPauseResumeToggle()
@@ -835,6 +841,7 @@ void QueueView::OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 caller
                 }
                 browser->sortByDiscIndex(); //sort tracks in album order
                 setQueueInitialState(browser->getTracks(false)); //only add available (playable) album tracks to the playqueue
+                setListViewState();
             }
         }
     }
